@@ -3,12 +3,13 @@
 #' @param fpcaObj Returned object from FPCA().
 #' @param subset A vector of indices or a logical vector for subsetting the
 #' observations.
-#' @param k The number of components to reconstruct the fitted sample paths.
+#' @param K The number of components to reconstruct the fitted sample paths.
 #' @param inputData A list of length 2 containing the sparse/dense
 #' (unsupported yet) observations. \code{inputData} needs to contain two
 #' fields: \code{Lt} for a list of time points and \code{Ly} for a list of
 #' observations. Default to the `inputData` field within `fpcaObj`.
 #' @param showObs Whether to plot the original observations for each subject.
+#' @param showMean Whether to plot the mean function as a bold solid curve.
 #' @param derOptns A list of options to control derivation parameters; see `fitted.FPCA'. (default = NULL)
 #' @param ... other arguments passed into matplot for plotting options
 #' @examples
@@ -23,11 +24,17 @@
 #' CreatePathPlot(res, subset=1:5)
 #' @export
 
-CreatePathPlot = function(fpcaObj, subset, k=NULL, inputData=fpcaObj[['inputData']], 
-                          showObs=!is.null(inputData),  
+CreatePathPlot = function(fpcaObj, subset, K=NULL, inputData=fpcaObj[['inputData']], 
+                          showObs=!is.null(inputData), showMean=FALSE, 
                           derOptns = NULL, ...){
   
   n <- dim(fpcaObj[['xiEst']])[1]
+  inargs <- list(...)
+  if (!is.null(inargs[['k']])) {
+    K <- inargs[['k']]
+    inargs[['k']] <- NULL
+    warning("specifying 'k' is deprecated. Use 'K' instead!")
+  }
   
   if (!is.null(derOptns[['p']]) && derOptns[['p']] >= 1 && missing(showObs)) {
   # makes no sense to show original observations with derivatives.
@@ -52,11 +59,10 @@ CreatePathPlot = function(fpcaObj, subset, k=NULL, inputData=fpcaObj[['inputData
   }
   # browser()
   workGrid <- fpcaObj[['workGrid']]
-  fit <- fitted(fpcaObj, k=k, derOptns = derOptns)[subset, , drop=FALSE]
+  fit <- fitted(fpcaObj, K=K, derOptns = derOptns)[subset, , drop=FALSE]
   
   defaultColPalette = rep(palette(), ceiling(nrow(fit)/7))[1:nrow(fit)]
   args1 <- list( xlab= 's', ylab= ' ',col = defaultColPalette)    
-  inargs <- list(...)
   args1[names(inargs)] <- inargs
   
   #matplot(obst, obsy, type='p',...)
@@ -75,6 +81,10 @@ CreatePathPlot = function(fpcaObj, subset, k=NULL, inputData=fpcaObj[['inputData
   } else {
       do.call(matplot, c(list(x=workGrid, y=t(fit), type='l'), args1))
   }
+  
+  if (showMean) {
+    lines(workGrid, fpcaObj[['mu']], lty=1, lwd=2)
+  }
    
   
   invisible()
