@@ -13,7 +13,7 @@
 #' \item{userBwMu}{The bandwidth value for the smoothed mean function (using 'CV' or 'GCV'); positive numeric - default: determine automatically based on 'methodBwMu'}
 #' \item{methodBwMu}{The bandwidth choice method for the mean function; 'GMeanAndGCV' (the geometric mean of the GCV bandwidth and the minimum bandwidth),'CV','GCV' - default: 5\% of the support} 
 #' \item{dataType}{The type of design we have (usually distinguishing between sparse or dense functional data); 'Sparse', 'Dense', 'DenseWithMV', 'p>>n' - default:  determine automatically based on 'IsRegular'}
-#' \item{diagnosticsPlot}{Make diagnostics plot (design plot, mean, scree plot and first k (<=3) eigenfunctions); logical - default: FALSE}
+#' \item{diagnosticsPlot}{Make diagnostics plot (design plot, mean, scree plot and first K (<=3) eigenfunctions); logical - default: FALSE}
 #' \item{error}{Assume measurement error in the dataset; logical - default: TRUE}
 #' \item{fitEigenValues}{Whether also to obtain a regression fit of the eigenvalues - default: FALSE}
 #' \item{FVEthreshold}{Fraction-of-Variance-Explained threshold used during the SVD of the fitted covar. function; numeric (0,1] - default: 0.9999}
@@ -224,9 +224,9 @@ FPCA = function(Ly, Lt, optns = list()){
     selectedK <- SelectK(fpcaObj = ret, criterion = optns$methodSelectK, FVEthreshold = optns$FVEthreshold)
   }
   
-  ret <- append(ret, list(selectK = selectedK$k, criterionValue = selectedK$criterion))
+  ret <- append(ret, list(selectK = selectedK$K, criterionValue = selectedK$criterion))
   class(ret) <- 'FPCA'
-  ret <- SubsetFPCA(fpcaObj = ret, k = ret$selectK)
+  ret <- SubsetFPCA(fpcaObj = ret, K = ret$selectK)
   
   # Make a quick diagnostics plot     
   if(optns$diagnosticsPlot){
