@@ -2,24 +2,28 @@
 #' given FPCA output and selection criteria
 #'
 #' @param fpcaObj A list containing FPCA related subjects returned by MakeFPCAResults().
-#' @param criterion A string or positive integer specifying selection criterion for number of functional principal components, available options: 'FVE', 'AIC', 'BIC', or the specified number of components - default: 'AIC'
+#' @param criterion A string or positive integer specifying selection criterion for number of functional principal components, available options: 'FVE', 'AIC', 'BIC', or the specified number of components - default: 'FVE'
 #' @param FVEthreshold A threshold percentage specified by user when using "FVE" as selection criterion: (0,1] - default: NULL
 #' @param Ly A list of \emph{n} vectors containing the observed values for each individual - default: NULL
 #' @param Lt A list of \emph{n} vectors containing the observation time points for each individual corresponding to Ly - default: NULL
 #'
 #' @return A list including the following two fields:
-#' \item{k}{An integer indicating the selected number of components based on given criterion.}
+#' \item{K}{An integer indicating the selected number of components based on given criterion.}
 #' \item{criterion}{The calculated criterion value for the selected number of components, i.e. FVE, AIC or BIC value, NULL for fixedK criterion.}
+#' \item{k}{Same as \code{K} for compatibility. WARNING: This will be removed in the next iteration}
 #'
 #' @export
 
-SelectK = function(fpcaObj, criterion = 'AIC', FVEthreshold = NULL, Ly = NULL, Lt = NULL){
+SelectK = function(fpcaObj, criterion = 'FVE', FVEthreshold = 0.95, Ly = NULL, Lt = NULL){
   if(class(fpcaObj) != 'FPCA'){
     stop('Invalid Input: not a FPCA object!')
   }
   if(is.null(criterion)){
     stop('Invalid selection criterion. Selection criterion must not be NULL!')
   }
+  if (length(criterion) != 1) {
+    stop('The length of criterion needs to be 1')
+  }
   if(!(criterion %in% c('FVE', 'AIC', 'BIC'))){
     if(is.numeric(criterion)){
       if(as.integer(criterion) != criterion || criterion <= 0){
@@ -50,25 +54,33 @@ SelectK = function(fpcaObj, criterion = 'AIC', FVEthreshold = NULL, Ly = NULL, L
       IC[i] = logliktemp + C * i
       if(i > 1 && IC[i] > IC[i-1]){
         # cease whenever AIC/BIC stops decreasing
-        return(list(k = i-1, criterion = IC[i-1]))
-      }
-      if(i == length(fpcaObj$lambda)){
-        return(list(k = i, criterion = IC[i]))
+        K <- i-1
+        criterion <- IC[i-1]
+      } else if(i == length(fpcaObj$lambda)){
+        K <- i
+        criterion <- IC[i]
       }
     }
     #if(criterion != 'FVE'){
-    #  return(k = length(fpcaObj$lambda))
+    #  return(K = length(fpcaObj$lambda))
     #}
   } else if(criterion == 'FVE'){
     # select FVE based on cumFVE in fpcaObj and specified FVEthreshold
     if(is.null(FVEthreshold)){stop('Need to specify FVEthreshold to choose number of components via FVE.')}
     cumFVE = fpcaObj$cumFVE
     buff <- .Machine[['double.eps']] * 100
-    return( list(k = min( which(cumFVE > FVEthreshold * 100 - buff) ), criterion = cumFVE[min(which(cumFVE > FVEthreshold * 100 - buff))]))
-  } else { # fixed K is specified.
+    K <- min( which(cumFVE > FVEthreshold * 100 - buff) )
+    criterion <- cumFVE[min(which(cumFVE > FVEthreshold * 100 - buff))]
+  } else if (is.numeric(criterion) && criterion > 0) { # fixed K is specified.
     if(criterion > length(fpcaObj$lambda)){
       stop("Specified number of components is more than available components.")
     }
-    return(list(k = criterion, criterion = NULL))
+    K <- criterion
+    criterion <- NULL
+  } else {
+    stop('Unknown criterion!')
   }
+  
+  # For compatibility reason, k is also returned.
+  return(list(K=K, criterion=criterion, k=K)) 
 }
