@@ -18,12 +18,12 @@
 #' @export
 print.FPCA <- function(x, ...){
   obj = x;
-  cat("Functional Principal Components Object for", tolower(obj$optns$dataType), "data.\n\n")
-  cat("The optimal number of components selected is:", length(obj$lambda),"and \nthe first k (<=3) eigenvalues are: ");
+  message(paste0("Functional Principal Components Object for", tolower(obj$optns$dataType), "data.\n\n"))
+  message(paste0("The optimal number of components selected is:", length(obj$lambda),"and \nthe first K (<=3) eigenvalues are: "))
   if ( length(obj$lambda) < 4) { 
-    cat( round(obj$lambda,3) ,"\n");
+    message(paste0( round(obj$lambda,3) ,"\n"))
   } else {
-    cat( round(obj$lambda[1:3],3) ,"\n")
+    message(paste0( round(obj$lambda[1:3],3) ,"\n"))
   }
 }
 
