@@ -19,12 +19,12 @@ print.FSVD <- function(x, ...){
     thisDataType <- 'DenseWithMV'
   }
     
-  cat("Functional Singular Value Decomposition object for", tolower(thisDataType), "data.\n\n")
-  cat("The optimal number of components selected is:", length(obj$sValues),"and \nthe first k (<=3) singular values are: ");
+  message(paste0("Functional Singular Value Decomposition object for", tolower(thisDataType), "data.\n\n"))
+  message(paste0("The optimal number of components selected is:", length(obj$sValues),"and \nthe first K (<=3) singular values are: "))
   if ( length(obj$sValues) < 4) { 
-    cat( round(obj$sValues,3) ,"\n");
+    message(paste0( round(obj$sValues,3) ,"\n"))
   } else {
-    cat( round(obj$sValues[1:3],3) ,"\n")
+    message(paste0(round(obj$sValues[1:3],3) ,"\n"))
   }
 }
 
